==> ukui-biometric-auth_1.0.3.orig.tar.gz: ukui-biometric-auth/polkit-agent/i18n_ts/es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>MainWindow</name>
    <message>
        <source>Form</source>
        <translation>Formar</translation>
    </message>
    <message>
        <source>Biometric</source>
        <translation>Biometrico</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalles</translation>
    </message>
    <message>
        <source>Polkit.subject-pid:</source>
        <translation>Polkit.subject-pid:</translation>
    </message>
    <message>
        <source>Vendor:</source>
        <translation>Vendedor:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Descripción:</translation>
    </message>
    <message>
        <source>Polkit.caller-pid:</source>
        <translation>Polkit.caller-pid:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Acción:</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Authenticate</source>
        <translation>Autenticar</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Autenticación</translation>
    </message>
    <message>
        <source>in authentication, please wait...</source>
        <translation>En autenticación, por favor espere ...</translation>
    </message>
    <message>
        <source>An application is attempting to perform an action that requires privileges. Authentication is required to perform this action.</source>
        <translation>Una aplicación está intentando realizar una acción que requiere privilegios. Se requiere autenticación para realizar esta acción.</translation>
    </message>
    <message>
        <source>Password: </source>
        <translation>Contraseña: </translation>
    </message>
    <message>
        <source>Authentication failed, please try again.</source>
        <translation>Autenticación fallida. Por favor intente de nuevo.</translation>
    </message>
</context>
<context>
    <name>PolkitListener</name>
    <message>
        <source>Another client is already authenticating, please try again later.</source>
        <translation>Otro cliente ya se está autenticando, inténtalo de nuevo más tarde.</translation>
    </message>
    <message>
        <source>Authentication failure, please try again.</source>
        <translation>Fallo de autenticación, por favor intente de nuevo.</translation>
    </message>
</context>
</TS>

==> ukui-biometric-auth_1.2.0.orig.tar.gz: ukui-biometric-auth/polkit-agent/i18n_ts/es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es">
<context>
    <name>MainWindow</name>
    <message>
        <source>Form</source>
        <translation>Formar</translation>
    </message>
    <message>
        <source>Biometric</source>
        <translation>Biometrico</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalles</translation>
    </message>
    <message>
        <source>Polkit.subject-pid:</source>
        <translation>Polkit.subject-pid:</translation>
    </message>
    <message>
        <source>Vendor:</source>
        <translation>Vendedor:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Descripción:</translation>
    </message>
    <message>
        <source>Polkit.caller-pid:</source>
        <translation>Polkit.caller-pid:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Acción:</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Authenticate</source>
        <translation>Autenticar</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Autenticación</translation>
    </message>
    <message>
        <source>in authentication, please wait...</source>
        <translation>En autenticación, por favor espere ...</translation>
    </message>
    <message>
        <source>An application is attempting to perform an action that requires privileges. Authentication is required to perform this action.</source>
        <translation>Una aplicación está intentando realizar una acción que requiere privilegios. Se requiere autenticación para realizar esta acción.</translation>
    </message>
    <message>
        <source>Password: </source>
        <translation>Contraseña: </translation>
    </message>
    <message>
        <source>Authentication failed, please try again.</source>
        <translation>Autenticación fallida. Por favor intente de nuevo.</translation>
    </message>
</context>
<context>
    <name>PolkitListener</name>
    <message>
        <source>Another client is already authenticating, please try again later.</source>
        <translation>Otro cliente ya se está autenticando, inténtalo de nuevo más tarde.</translation>
    </message>
    <message>
        <source>Authentication failure, please try again.</source>
        <translation>Fallo de autenticación, por favor intente de nuevo.</translation>
    </message>
    <message>
        <source>Account locked %1 minutes due to %2 fail attempts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Authentication failure,there are still %1 remaining opportunities</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
